pydatajson package
==================

Submodules
----------

pydatajson.ckan_reader module
-----------------------------

.. automodule:: pydatajson.ckan_reader
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.core module
----------------------

.. automodule:: pydatajson.core
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.custom_exceptions module
-----------------------------------

.. automodule:: pydatajson.custom_exceptions
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.helpers module
-------------------------

.. automodule:: pydatajson.helpers
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.readers module
-------------------------

.. automodule:: pydatajson.readers
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.writers module
-------------------------

.. automodule:: pydatajson.writers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pydatajson
    :members:
    :undoc-members:
    :show-inheritance:
